import"./jwt-decode.esm-DyyavT6h.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="c6066a1d-9f58-43e0-9cba-273f8ef46a34",e._sentryDebugIdIdentifier="sentry-dbid-c6066a1d-9f58-43e0-9cba-273f8ef46a34")}catch{}})();const l=1e3,s=e=>{let n=null;return{startPolling:()=>{const t=async()=>{try{!document.hidden&&!e.keepPollingOnOutOfFocus&&await e.task()}finally{n=setTimeout(t,e.interval??l)}};t()},endPolling:()=>{n&&clearTimeout(n)}}};export{s as u};
//# sourceMappingURL=polling-Bym9DFkz.js.map
