const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-24Ro8cB1.js","assets/workspaceStore-CxCWsO27.js","assets/jwt-decode.esm-DyyavT6h.js","assets/jwt-decode-D9e-DIPp.css","assets/userStore-CViq8J7-.js","assets/url-CaxRUwff.js","assets/colorHelpers-sG7zU7Nm.js","assets/OidcLogoutCallback-DNH9sH8S.js","assets/Login-DJRMeKcb.js","assets/Login.vue_vue_type_script_setup_true_lang-nM9tMueD.js","assets/OTPInput-CPuVANSf.js","assets/OTPInput-C8ldH5jb.css","assets/Logo-BLceuW0a.js","assets/Logo-D2kepPyK.css","assets/string-C33uYcCb.js","assets/CircularLoading-dfNnamlc.js","assets/CircularLoading-BiyobKo3.css","assets/index-Bo37hDDz.js","assets/Login-cMuNqCbG.css","assets/Login-C1k-SC0u.css","assets/Main-B43fRL2Z.js","assets/PlayerNavbar-DLwGdy7s.js","assets/metadata-Y6zgvVoL.js","assets/PhMagnifyingGlass.vue-CnnGcq_x.js","assets/PhWebhooksLogo.vue-C4ER29VB.js","assets/LoadingOutlined-BHD4p6lx.js","assets/PhSignOut.vue-hw-7sNAH.js","assets/index-CHZRANF0.js","assets/PlayerNavbar-VlEtzX8f.css","assets/Main-DqPmGmnC.css","assets/Home-kRuWIXn-.js","assets/Watermark-DUfCHBD4.js","assets/constants-BEk-t5le.js","assets/Watermark-DMbnzHiR.css","assets/PhArrowSquareOut.vue-ByXC47Qj.js","assets/index-CO1CcaGf.js","assets/Home-B6UGln4L.css","assets/Error-BrWDE1KP.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-CirEJagM.js","assets/Error-CIbhyrKS.css","assets/Form-5h8mHuGs.js","assets/FormRunner-BX1e2lO1.js","assets/Steps-Ctz0ASy3.js","assets/index-BKkWnkAX.js","assets/Steps-DqO_G9S3.css","assets/FormRunner-Fkp92u0R.css","assets/redirect-DpBTr3iX.js","assets/asyncComputed-D5HqUDwR.js","assets/uuid-DHL8I4Aa.js","assets/Form-CshGBPDC.css"])))=>i.map(i=>d[i]);
import{ag as s,ah as d,ad as t,ai as m}from"./jwt-decode.esm-DyyavT6h.js";import{a as u}from"./workspaceStore-CxCWsO27.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="f3cefb05-d259-481a-b0a8-bf3fc0b7facf",a._sentryDebugIdIdentifier="sentry-dbid-f3cefb05-d259-481a-b0a8-bf3fc0b7facf")}catch{}})();const h=async()=>{try{const a=await fetch("/_editor/api/workspace/version");return a.ok&&(await a.json()).version||"6c3c1e7e02e97ab643f29989bf9b1508062aba5d"}catch(a){return console.error("Failed to fetch Abstra version:",a),"6c3c1e7e02e97ab643f29989bf9b1508062aba5d"}},p=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-24Ro8cB1.js"),__vite__mapDeps([0,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-DNH9sH8S.js"),__vite__mapDeps([7,1,2,3,4,5,6])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-DJRMeKcb.js"),__vite__mapDeps([8,9,2,3,1,4,5,6,10,11,12,13,14,15,16,17,18,19])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-B43fRL2Z.js"),__vite__mapDeps([20,21,4,2,3,1,5,6,22,23,24,25,26,27,28,29])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-kRuWIXn-.js"),__vite__mapDeps([30,22,2,3,23,24,31,1,4,5,6,32,33,34,35,25,36])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-BrWDE1KP.js"),__vite__mapDeps([37,38,12,2,3,13,32,1,4,5,6,35,39])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-5h8mHuGs.js"),__vite__mapDeps([40,4,2,3,41,9,1,5,6,10,11,12,13,14,15,16,17,18,42,43,44,31,32,33,45,46,47,48,49])),meta:{hideLogin:!0}}]}],o=s({history:d("/"),routes:p,scrollBehavior(a){if(a.hash)return{el:a.hash}}}),l=a=>async(e,r)=>{if(m(e,r),e.meta.allowUnauthenticated)return;const n=await u(e.path),{redirect:i,...c}=e.query;switch(n.status){case"ALLOWED":break;case"UNAUTHORIZED":await a.push({name:"playerLogin",query:{...c,redirect:i||e.path},params:e.params});break;case"NOT_FOUND":await a.push({name:"error",params:{status:"404"}});break;default:await a.push({name:"error",params:{status:"403"}})}};o.beforeEach(l(o));export{p as a,l as b,h as g,o as r};
//# sourceMappingURL=router-CCmSb2qD.js.map
