import{O as l}from"./workspaceStore-CxCWsO27.js";import{a as d,D as u,b as f,j as o,w as n,u as t,aj as _,ak as b,S as r,U as s,af as c,e as p}from"./jwt-decode.esm-DyyavT6h.js";import"./userStore-CViq8J7-.js";import"./url-CaxRUwff.js";import"./colorHelpers-sG7zU7Nm.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="6464ca29-c13c-43f9-bbfd-ab4c59a5733e",e._sentryDebugIdIdentifier="sentry-dbid-6464ca29-c13c-43f9-bbfd-ab4c59a5733e")}catch{}})();const D=d({__name:"OidcLogoutCallback",setup(e){return u(async()=>{await new l().logoutCallback()}),(a,i)=>(p(),f("div",null,[o(t(_),null,{default:n(()=>[r(s(t(c).translate("i18n_oidclogoutcallback_authenticated_title")),1)]),_:1}),o(t(b),null,{default:n(()=>[r(s(t(c).translate("i18n_oidclogoutcallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLogoutCallback-DNH9sH8S.js.map
