import{u as s}from"./userStore-CViq8J7-.js";import{W as n}from"./PlayerConfigProvider-p6pfp1dg.js";import{u as c}from"./workspaceStore-CxCWsO27.js";import{a as f,H as i,p as d,g as p,u as o,w as u,j as m,a4 as l,e as w}from"./jwt-decode.esm-DyyavT6h.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="9a8997d2-36fa-4b65-84fb-59204f94259b",t._sentryDebugIdIdentifier="sentry-dbid-9a8997d2-36fa-4b65-84fb-59204f94259b")}catch{}})();const C=f({__name:"App",setup(t){const a=s(),e=c();return e.actions.fetch(),i(()=>a.jwt,e.actions.fetch),(_,b)=>{const r=l("RouterView");return o(e).state.workspace?(w(),d(n,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:u(()=>[m(r,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):p("",!0)}}});export{C as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang-DnEm_CAX.js.map
