.table-card[data-v-e197befa]{height:100%;width:100%;transition:all .3s ease}.table-card[data-v-e197befa]:hover{transform:translateY(-2px);box-shadow:0 4px 12px #00000026}.columns-list[data-v-e197befa]{max-height:280px;overflow-y:auto;overflow-x:hidden}.column-row[data-v-e197befa]{padding:4px 0;position:relative;min-width:0;transition:all .2s ease}.column-highlighted[data-v-e197befa],.more-columns-highlighted[data-v-e197befa]{background-color:#e6f7ff}.table-highlighted[data-v-e197befa]{border:2px solid #1890ff;box-shadow:0 0 0 2px #1890ff33}.key-icon[data-v-e197befa]{color:#faad14;flex-shrink:0}.type-tag[data-v-e197befa]{font-size:11px;padding:0 8px;margin:0;border-radius:4px;white-space:nowrap;flex-shrink:0}
