.execution-card[data-v-68e9de78]{border-radius:8px;margin-bottom:12px;border:1px solid #e5e7eb;overflow:hidden;background-color:#fff;box-shadow:0 1px 2px #00000008}.execution-card[data-v-68e9de78]:hover{border-color:#d1d5db}.execution-header[data-v-68e9de78]{display:flex;align-items:center;justify-content:space-between;width:100%;gap:16px}.execution-header-left[data-v-68e9de78]{display:flex;align-items:center;gap:12px;min-width:0}.status-dot[data-v-68e9de78]{width:10px;height:10px;border-radius:50%;flex-shrink:0}.status-spinner[data-v-68e9de78]{width:14px;height:14px;display:flex;align-items:center;justify-content:center;flex-shrink:0;color:#1890ff;font-size:14px}.status-dot.finished[data-v-68e9de78]{background:#52c41a}.status-dot.failed[data-v-68e9de78]{background:#ff4d4f}.status-dot.abandoned[data-v-68e9de78]{background:#faad14}.execution-info[data-v-68e9de78]{display:flex;flex-direction:column;min-width:0}.execution-stage[data-v-68e9de78]{font-weight:500;font-size:14px;color:#1f2937;white-space:nowrap;overflow:hidden;text-overflow:ellipsis}.execution-meta[data-v-68e9de78]{font-size:12px;color:#9ca3af;font-family:ui-monospace,SFMono-Regular,SF Mono,Menlo,Monaco,Liberation Mono,monospace}.execution-time[data-v-68e9de78]{font-size:12px;color:#6b7280;white-space:nowrap;flex-shrink:0;position:relative;cursor:default;margin-right:8px}.execution-time .time-relative[data-v-68e9de78],.execution-time .time-exact[data-v-68e9de78]{transition:opacity .2s ease,transform .2s ease}.execution-time .time-exact[data-v-68e9de78]{position:absolute;right:0;opacity:0;transform:translateY(-2px)}.execution-time:hover .time-relative[data-v-68e9de78]{opacity:0;transform:translateY(2px)}.execution-time:hover .time-exact[data-v-68e9de78]{opacity:1;transform:translateY(0)}.execution-actions-trigger[data-v-68e9de78]{display:flex;align-items:center;justify-content:center;width:28px;height:28px;border-radius:6px;cursor:pointer;color:#9ca3af;transition:all .15s}.execution-actions-trigger[data-v-68e9de78]:hover{background:#f3f4f6;color:#374151}[data-v-68e9de78] .execution-card>.ant-collapse-header{padding:12px 16px!important;align-items:center!important}[data-v-68e9de78] .execution-card>.ant-collapse-content>.ant-collapse-content-box{padding:16px!important}.execution-card[data-v-68e9de78]:last-child{border-radius:8px;border:1px solid #e5e7eb}
