import{C as p,_ as n}from"./View.vue_vue_type_script_setup_true_lang-DAqfrI1o.js";import{a as i,ac as s,p as a,e as m,u as d}from"./jwt-decode.esm-DyyavT6h.js";import"./router-BhKBgDIv.js";import"./ts.worker-Do44s_XH.js";import"./fetch-BaAgCW4y.js";import"./record-Dva_8M1P.js";import"./SaveButton-B1RTX8sL.js";import"./ExclamationCircleOutlined-xUHIZHGs.js";import"./CrudView-DB2mMVy_.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-BZXWm6NO.js";import"./constants-BEk-t5le.js";import"./url-CaxRUwff.js";import"./PhDotsThreeVertical.vue-BXrShwWD.js";import"./index-DdqJ9EQR.js";import"./asyncComputed-D5HqUDwR.js";import"./omniChatStore-n1MkGLEa.js";import"./uuid-DHL8I4Aa.js";import"./PhCopySimple.vue-qVDAfznd.js";import"./PhPencil.vue-9qE0PBL8.js";import"./useCodebaseEvents-CB5c_tQY.js";import"./contracts.generated-BCUElS1n.js";import"./index-Bo37hDDz.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="2549ab74-6ac0-414e-b88d-6d2dd0806055",o._sentryDebugIdIdentifier="sentry-dbid-2549ab74-6ac0-414e-b88d-6d2dd0806055")}catch{}})();const A=i({__name:"EnvVars",setup(o){const t=s().params.projectId,e=new p(t);return(c,u)=>(m(),a(n,{"env-var-repository":d(e),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars-Dpc6h-nO.js.map
