import{a as i,c as o,b as s,g as c,E as l,U as f,bc as g,e as t,aN as u}from"./jwt-decode.esm-DyyavT6h.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="c9de63b0-0ec2-4ff8-9fc6-2a7bc0de80c0",e._sentryDebugIdIdentifier="sentry-dbid-c9de63b0-0ec2-4ff8-9fc6-2a7bc0de80c0")}catch{}})();const m={class:"logo"},b=["src","alt"],y=i({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){g(d=>({v4521d904:n.value}));const a=e,n=o(()=>a.size==="small"?"24px":a.size==="large"?"80px":"50px"),r=o(()=>`${a.brandName} Logo`);return(d,p)=>(t(),s("div",m,[e.imageUrl?(t(),s("img",{key:0,class:"logo-img",src:e.imageUrl,alt:r.value},null,8,b)):c("",!0),e.hideText?c("",!0):(t(),s("span",{key:1,class:l(e.size)},f(e.brandName),3))]))}}),_=u(y,[["__scopeId","data-v-8f34aac0"]]);export{_ as L};
//# sourceMappingURL=Logo-BLceuW0a.js.map
