import{a as c,c as b,p as d,e as r,u as a,A as g,w as n,j as l,B as i,q as p,t as m,v as u,f,g as y,m as B}from"./jwt-decode.esm-DyyavT6h.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="9af0bbe6-015d-4dab-b416-3ab5906cde1f",e._sentryDebugIdIdentifier="sentry-dbid-9af0bbe6-015d-4dab-b416-3ab5906cde1f")}catch{}})();const _=c({__name:"AbstraButton",props:{disabledTooltip:{},tooltip:{},prefixCls:{},type:{},htmlType:{},shape:{},size:{},loading:{type:[Boolean,Object]},disabled:{type:Boolean},ghost:{type:Boolean},block:{type:Boolean},danger:{type:Boolean},icon:{},href:{},target:{},title:{},onClick:{type:[Function,Array]},onMousedown:{type:[Function,Array]}},setup(e){const t=b(()=>o.disabledTooltip&&o.disabled?o.disabledTooltip:o.tooltip),o=e;return(s,k)=>t.value?(r(),d(a(g),{key:0,title:t.value},{default:n(()=>[l(a(i),p(m(s.$props)),{default:n(()=>[l(a(u),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:n(()=>[e.loading?y("",!0):f(s.$slots,"default",{key:0})]),_:3})]),_:3},16)]),_:3},8,["title"])):(r(),d(a(i),p(B({key:1},s.$props)),{default:n(()=>[l(a(u),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:n(()=>[e.loading?y("",!0):f(s.$slots,"default",{key:0})]),_:3})]),_:3},16))}});export{_};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang-C8pP27Qo.js.map
