import{a as d,c as s,b as l,e as i,E as a,h as r,f as c,K as f,aN as u}from"./jwt-decode.esm-DyyavT6h.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="0cafb082-f9b5-4673-a15b-461e9322eda4",e._sentryDebugIdIdentifier="sentry-dbid-0cafb082-f9b5-4673-a15b-461e9322eda4")}catch{}})();const y=d({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean},flexLayout:{type:Boolean},innerPadding:{}},setup(e){const n=e,t=s(()=>({...n.innerPadding&&{padding:n.innerPadding}}));return(o,b)=>(i(),l("div",{class:a(["content-layout",{"no-padding":e.noPadding}])},[r("div",{class:a(["centered-layout",{"full-width":e.fullWidth,"flex-layout":e.flexLayout}]),style:f(t.value)},[c(o.$slots,"default",{},void 0,!0)],6)],2))}}),g=u(y,[["__scopeId","data-v-00e066e8"]]);export{g as C};
//# sourceMappingURL=ContentLayout-t6MXItbR.js.map
