import{aR as r,aS as n,a5 as o,aT as d,aU as p,aV as c,aW as f,aX as m,aY as u,aZ as s,a_ as g,a$ as b,b0 as l}from"./jwt-decode.esm-DyyavT6h.js";import{g as y,r as i}from"./router-CCmSb2qD.js";import{s as w}from"./workspaceStore-CxCWsO27.js";import{_}from"./App.vue_vue_type_style_index_0_lang-DnEm_CAX.js";import"./userStore-CViq8J7-.js";import"./url-CaxRUwff.js";import"./colorHelpers-sG7zU7Nm.js";import"./PlayerConfigProvider-p6pfp1dg.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="138f68b5-95d7-48b6-a7fd-625975775e4d",t._sentryDebugIdIdentifier="sentry-dbid-138f68b5-95d7-48b6-a7fd-625975775e4d")}catch{}})();class h{static init(){setInterval(()=>{fetch("/_healthcheck").catch(()=>{})},20*1e3)}}(async()=>{await w();const t=await y(),a=r(),e=n({render:()=>o(_)});d.init(),p(e,i,t),h.init(),e.use(i),e.use(a),e.use(c),e.mount("#app"),e.component("VSelect",f),e.component("Markdown",m),e.component("Message",u),s(e,g),s(e,b),s(e,l)})();
//# sourceMappingURL=player-qklxPh02.js.map
