import{L as u}from"./CircularLoading-dfNnamlc.js";import{a as f,ac as p,D as h,b as _,e as l,h as d,j as g,aN as m}from"./jwt-decode.esm-DyyavT6h.js";import{E as a,b as y}from"./router-BhKBgDIv.js";import"./ts.worker-Do44s_XH.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="5153c182-4f2f-48d0-84e7-e45366a0040a",e._sentryDebugIdIdentifier="sentry-dbid-5153c182-4f2f-48d0-84e7-e45366a0040a")}catch{}})();const w={class:"authorize"},b={class:"content"},A=f({__name:"Authorize",setup(e){const o=p();return h(()=>{const{client_id:r,redirect_uri:s,response_type:n,state:i}=o.query,t=a.cloudApi.startsWith("https://")||a.cloudApi.startsWith("http://")?new URL(`${a.cloudApi}/oauth/authorize`):new URL(`${location.origin}${a.cloudApi}/oauth/authorize`);typeof r=="string"&&t.searchParams.set("client_id",r),typeof s=="string"&&t.searchParams.set("redirect_uri",s),typeof n=="string"&&t.searchParams.set("response_type",n),typeof i=="string"&&t.searchParams.set("state",i);const c=y.getAuthor();c?.jwt&&t.searchParams.set("session_token",c.jwt),window.location.href=t.toString()}),(r,s)=>(l(),_("div",w,[d("div",b,[s[0]||(s[0]=d("h1",null,"Authorizing...",-1)),g(u)])]))}}),L=m(A,[["__scopeId","data-v-57fe5408"]]);export{L as default};
//# sourceMappingURL=Authorize-C2ZwuTDl.js.map
