(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="e8dd4ffd-57be-43f8-84bd-fa6ed011ec1f",e._sentryDebugIdIdentifier="sentry-dbid-e8dd4ffd-57be-43f8-84bd-fa6ed011ec1f")}catch{}})();function t(e){var n=e.match(/^\s*\S/);return e.skipToEnd(),n?"error":null}const f={name:"asciiarmor",token:function(e,n){var r;if(n.state=="top")return e.sol()&&(r=e.match(/^-----BEGIN (.*)?-----\s*$/))?(n.state="headers",n.type=r[1],"tag"):t(e);if(n.state=="headers"){if(e.sol()&&e.match(/^\w+:/))return n.state="header","atom";var d=t(e);return d&&(n.state="body"),d}else{if(n.state=="header")return e.skipToEnd(),n.state="headers","string";if(n.state=="body")return e.sol()&&(r=e.match(/^-----END (.*)?-----\s*$/))?r[1]!=n.type?"error":(n.state="end","tag"):e.eatWhile(/[A-Za-z0-9+\/=]/)?null:(e.next(),"error");if(n.state=="end")return t(e)}},blankLine:function(e){e.state=="headers"&&(e.state="body")},startState:function(){return{state:"top",type:null}}};export{f as asciiArmor};
//# sourceMappingURL=asciiarmor-BjKO5odn.js.map
