import{O as l}from"./workspaceStore-CxCWsO27.js";import{a as c,D as f,b as u,j as n,w as o,u as t,aj as _,ak as b,S as r,U as s,af as i,e as p}from"./jwt-decode.esm-DyyavT6h.js";import"./userStore-CViq8J7-.js";import"./url-CaxRUwff.js";import"./colorHelpers-sG7zU7Nm.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="7e549d14-fa0e-42fb-b214-e2d0fdc3e904",e._sentryDebugIdIdentifier="sentry-dbid-7e549d14-fa0e-42fb-b214-e2d0fdc3e904")}catch{}})();const D=c({__name:"OidcLoginCallback",setup(e){return f(async()=>{await new l().loginCallback()}),(a,d)=>(p(),u("div",null,[n(t(_),null,{default:o(()=>[r(s(t(i).translate("i18n_oidclogincallback_authenticated_title")),1)]),_:1}),n(t(b),null,{default:o(()=>[r(s(t(i).translate("i18n_oidclogincallback_close_window_message")),1)]),_:1})]))}});export{D as default};
//# sourceMappingURL=OidcLoginCallback-24Ro8cB1.js.map
