import{a as t,b as s,e as o,j as d,u as r,b7 as c,aN as i}from"./jwt-decode.esm-DyyavT6h.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="2ede3d52-471f-4596-ba77-74e225b9a460",e._sentryDebugIdIdentifier="sentry-dbid-2ede3d52-471f-4596-ba77-74e225b9a460")}catch{}})();const _={class:"centered"},f=t({__name:"LoadingContainer",setup(e){return(n,a)=>(o(),s("div",_,[d(r(c))]))}}),p=i(f,[["__scopeId","data-v-52e6209a"]]);export{p as L};
//# sourceMappingURL=LoadingContainer-BRwcRXny.js.map
