import{_ as m}from"./AbstraLogo.vue_vue_type_script_setup_true_lang-CirEJagM.js";import{B as y}from"./BaseLayout-NniIuGaa.js";import{a as l,P as _,a1 as b,aN as u,aG as v,aH as g,e as f,b as h,h as o,K as s,D as w,ae as S,p as k,w as n,ac as B,j as i,u as I}from"./jwt-decode.esm-DyyavT6h.js";import{u as $}from"./editor-DMWkSwBI.js";import{A as D}from"./index-CREYrgWF.js";import"./Logo-BLceuW0a.js";import"./router-CCmSb2qD.js";import"./workspaceStore-CxCWsO27.js";import"./userStore-CViq8J7-.js";import"./url-CaxRUwff.js";import"./colorHelpers-sG7zU7Nm.js";import"./useCodebaseEvents-CB5c_tQY.js";import"./contracts.generated-BCUElS1n.js";import"./ts.worker-Do44s_XH.js";import"./constants-BEk-t5le.js";import"./linters-xND8Zwy-.js";import"./asyncComputed-D5HqUDwR.js";import"./index-DdqJ9EQR.js";import"./index-CHZRANF0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="e425dfc8-a9bb-43e6-a997-6228138311a3",e._sentryDebugIdIdentifier="sentry-dbid-e425dfc8-a9bb-43e6-a997-6228138311a3")}catch{}})();const L=l({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const r=_({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(r)}}}),P={class:"v-spinner"};function x(e,r,a,d,c,p){return v((f(),h("div",P,[o("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-even",style:s(e.spinnerStyle)},null,4),o("div",{class:"v-beat v-beat-odd",style:s(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const K=u(L,[["render",x],["__scopeId","data-v-06538001"]]),R={class:"content"},j=l({__name:"ProjectLogin",setup(e){const r=B(),a=S(),d=$();function c(){const t=new URL(location.href);t.searchParams.delete("api-key"),a.replace(t.pathname+t.search)}function p(){const t=r.query["api-key"];if(typeof t=="string")return t}return w(async()=>{const t=p();if(!t){a.push({name:"error"});return}await d.createLogin(t).then(c),a.push({name:"editor"})}),(t,z)=>(f(),k(y,null,{navbar:n(()=>[i(I(D),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:n(()=>[i(m)]),_:1})]),content:n(()=>[o("div",R,[i(K)])]),_:1}))}}),ee=u(j,[["__scopeId","data-v-d2a19803"]]);export{ee as default};
//# sourceMappingURL=ProjectLogin-Bv4XvaBF.js.map
