import{A as n}from"./index-BKkWnkAX.js";import{a,c as o,b as r,g as c,E as f,j as d,u as l,e as p,aN as i}from"./jwt-decode.esm-DyyavT6h.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="f39a66e9-a859-4e63-928d-b2c3f309ad92",e._sentryDebugIdIdentifier="sentry-dbid-f39a66e9-a859-4e63-928d-b2c3f309ad92")}catch{}})();const u=a({__name:"Steps",props:{stepsInfo:{},isPreview:{type:Boolean}},setup(e){const s=e,t=o(()=>s.stepsInfo?Array(s.stepsInfo.total).fill(null).map(()=>({label:"",description:""})):[]);return(m,y)=>e.stepsInfo?(p(),r("nav",{key:0,class:f(["p-steps",{"full-screen":!e.isPreview}])},[d(l(n),{current:e.stepsInfo.current-1,items:t.value,responsive:!1},null,8,["current","items"])],2)):c("",!0)}}),_=i(u,[["__scopeId","data-v-58fdd395"]]);export{_ as S};
//# sourceMappingURL=Steps-Ctz0ASy3.js.map
