.logo[data-v-8f34aac0]{display:flex;gap:5px;align-items:center}.logo .logo-img[data-v-8f34aac0]{height:var(--v4521d904);max-width:100%}.logo span.small[data-v-8f34aac0]{font-size:12px;font-size:14px;font-weight:600}.logo span.medium[data-v-8f34aac0]{font-size:14px;font-size:16px;font-weight:600}.logo span.large[data-v-8f34aac0]{font-size:16px;font-size:18px;font-weight:600}
