[data-v-3ce1506a]:root{--main-font-family: DM Sans, sans-serif}[data-v-3ce1506a]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-3ce1506a]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-3ce1506a]{background-color:#fff;padding:10px}.loading-container[data-v-3ce1506a],.error-container[data-v-3ce1506a]{display:flex;flex-direction:column;align-items:center;justify-content:center;height:100%;gap:16px;padding:40px}.error-message[data-v-3ce1506a]{color:#d35249;font-size:14px}[data-v-f3162ce8]:root{--main-font-family: DM Sans, sans-serif}[data-v-f3162ce8]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-f3162ce8]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-f3162ce8]{background-color:#fff;padding:10px}.loading-container[data-v-f3162ce8],.error-container[data-v-f3162ce8]{display:flex;flex-direction:column;align-items:center;justify-content:center;height:100%;gap:16px;padding:40px}.error-message[data-v-f3162ce8]{color:#d35249;font-size:14px}.code-viewer-container[data-v-f3162ce8]{width:100%;height:100%;overflow:hidden}[data-v-e1a51961]:root{--main-font-family: DM Sans, sans-serif}[data-v-e1a51961]:root{--abstra-main-color-dark: #343b46}.p-dropdown[data-v-e1a51961]{border-radius:8px;border:1px solid #343b46;background-color:#fff;height:37px;padding:0 10px;align-items:center}.p-dropdown-panel[data-v-e1a51961]{background-color:#fff;padding:10px}.files-container[data-v-e1a51961]{width:100%;height:calc(100vh - 140px);margin-bottom:30px;box-sizing:border-box;display:flex;flex-direction:column;gap:16px}.files-card[data-v-e1a51961]{flex-grow:1;display:flex;flex-direction:column;overflow:hidden}.files-card[data-v-e1a51961] .ant-card-body{flex-grow:1;display:flex;flex-direction:column;padding:16px;overflow:hidden}.files-card[data-v-e1a51961] .ant-tabs{flex-grow:1;display:flex;flex-direction:column;overflow:hidden}.files-card[data-v-e1a51961] .ant-tabs-content-holder{flex-grow:1;overflow:hidden}.files-card[data-v-e1a51961] .ant-tabs-content{height:100%}.files-card[data-v-e1a51961] .ant-tabs-tabpane{height:100%;overflow:auto}.pdf-viewer-container[data-v-e1a51961]{width:100%;height:100%;display:flex;flex-direction:column;align-items:center;justify-content:center;background-color:#525659}.pdf-viewer-container .pdf-object[data-v-e1a51961]{width:100%;height:100%;border:none}.pdf-viewer-container .pdf-loading[data-v-e1a51961],.pdf-viewer-container .pdf-fallback[data-v-e1a51961]{color:#fff;font-size:16px;text-align:center;padding:20px}.tab-content[data-v-e1a51961]{height:100%;overflow:auto}
