import{i as h}from"./metadata-Y6zgvVoL.js";import{W as w}from"./Watermark-DUfCHBD4.js";import{F as b}from"./PhArrowSquareOut.vue-ByXC47Qj.js";import{a as v,c as x,r as C,b as u,g as D,u as e,j as p,w as s,v as f,p as r,S as y,U as _,af as I,b1 as g,M as z,W as F,ae as N,e as t,E as S,R as W,aN as B}from"./jwt-decode.esm-DyyavT6h.js";import{u as E}from"./workspaceStore-CxCWsO27.js";import{C as L}from"./index-CO1CcaGf.js";import{L as T}from"./LoadingOutlined-BHD4p6lx.js";import"./PhMagnifyingGlass.vue-CnnGcq_x.js";import"./PhWebhooksLogo.vue-C4ER29VB.js";import"./constants-BEk-t5le.js";import"./userStore-CViq8J7-.js";import"./url-CaxRUwff.js";import"./colorHelpers-sG7zU7Nm.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[n]="0fde178a-821c-4793-b3e1-c576eac04323",o._sentryDebugIdIdentifier="sentry-dbid-0fde178a-821c-4793-b3e1-c576eac04323")}catch{}})();const V={key:0,class:"home-container"},j=v({__name:"Home",setup(o){const n=N(),i=E(),d=x(()=>i.state.workspace?.sidebar.filter(c=>c.id!=="home")||[]),l=C(null),k=async(c,m)=>{l.value=m,await n.push({path:`/${c}`}),l.value=null};return(c,m)=>e(i).state.workspace?(t(),u("div",V,[p(e(f),{vertical:"",gap:"large",class:"cards-container"},{default:s(()=>[d.value.length===0?(t(),r(e(g),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:s(()=>[y(_(e(I).translate("i18n_home_no_forms_available")),1)]),_:1})):(t(!0),u(z,{key:1},F(d.value,a=>(t(),r(e(L),{key:a.id,class:S(["form-card",{loading:l.value===a.id}]),"body-style":{cursor:"pointer"},onClick:H=>k(a.path,a.id)},{default:s(()=>[p(e(f),{gap:"large",align:"center",justify:"space-between"},{default:s(()=>[(t(),r(W(e(h)(a.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),p(e(g),{style:{"font-size":"18px","font-weight":"500"}},{default:s(()=>[y(_(a.name),1)]),_:2},1024),l.value!==a.id?(t(),r(e(b),{key:0,size:"20"})):(t(),r(e(T),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),p(w,{class:"watermark","page-id":"home",locale:e(i).state.workspace.language},null,8,["locale"])])):D("",!0)}}),Y=B(j,[["__scopeId","data-v-2dd12c4e"]]);export{Y as default};
//# sourceMappingURL=Home-kRuWIXn-.js.map
