import{P as g}from"./PlayerNavbar-DLwGdy7s.js";import{a as _,ac as c,r as h,c as b,b as y,p as k,g as v,h as w,u as n,j as L,a4 as C,ae as N,e as i,aN as I}from"./jwt-decode.esm-DyyavT6h.js";import{u as V}from"./workspaceStore-CxCWsO27.js";import"./userStore-CViq8J7-.js";import"./metadata-Y6zgvVoL.js";import"./PhMagnifyingGlass.vue-CnnGcq_x.js";import"./PhWebhooksLogo.vue-C4ER29VB.js";import"./LoadingOutlined-BHD4p6lx.js";import"./PhSignOut.vue-hw-7sNAH.js";import"./index-CHZRANF0.js";import"./url-CaxRUwff.js";import"./colorHelpers-sG7zU7Nm.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="db36465c-17af-4d79-8a05-d537aceb468a",a._sentryDebugIdIdentifier="sentry-dbid-db36465c-17af-4d79-8a05-d537aceb468a")}catch{}})();const B={class:"main-container"},D={class:"content"},R=_({__name:"Main",setup(a){const e=N(),o=V(),d=c().path,t=h(null),u=async({path:r,id:s})=>{t.value=s,await e.push({path:`/${r}`}),t.value=null},p=()=>{e.push({name:"playerLogin"})},l=()=>{e.push({name:"playerLogin"})},m=b(()=>!!c().meta.hideLogin);return(r,s)=>{const f=C("RouterView");return i(),y("div",B,[n(o).state.workspace?(i(),k(g,{key:0,"current-path":n(d),"hide-login":m.value,"runner-data":n(o).state.workspace,loading:t.value,onNavigate:u,onLoginClick:l,onLogoutClick:p},null,8,["current-path","hide-login","runner-data","loading"])):v("",!0),w("section",D,[L(f)])])}}}),G=I(R,[["__scopeId","data-v-f095bece"]]);export{G as default};
//# sourceMappingURL=Main-B43fRL2Z.js.map
