import{O as s}from"./OmniChat-BY29TP7e.js";import{u as a}from"./omniChatStore-n1MkGLEa.js";import{a as c,ac as i,p as d,g as u,u as t,e as l}from"./jwt-decode.esm-DyyavT6h.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="38a3d9ea-f67d-4f11-845a-a9ed7026c219",e._sentryDebugIdIdentifier="sentry-dbid-38a3d9ea-f67d-4f11-845a-a9ed7026c219")}catch{}})();const g=c({__name:"ConsoleOmniChat",setup(e){const n=i().params.projectId,o=a();return o.init("console",n),(p,f)=>t(o).controller&&t(o).repository?(l(),d(s,{key:0,"ai-chat-repository":t(o).repository,controller:t(o).controller,environment:{origin:"console",projectId:t(n)},"show-console-suggestions":!0},null,8,["ai-chat-repository","controller","environment"])):u("",!0)}});export{g as _};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang-CrYB34FN.js.map
