import{_ as p}from"./Login.vue_vue_type_script_setup_true_lang-nM9tMueD.js";import{a as u,b as i,j as d,u as n,ae as m,ac as l,e as _,aN as f}from"./jwt-decode.esm-DyyavT6h.js";import{u as b}from"./workspaceStore-CxCWsO27.js";import"./OTPInput-CPuVANSf.js";import"./Logo-BLceuW0a.js";import"./string-C33uYcCb.js";import"./CircularLoading-dfNnamlc.js";import"./index-Bo37hDDz.js";import"./userStore-CViq8J7-.js";import"./url-CaxRUwff.js";import"./colorHelpers-sG7zU7Nm.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="a1c04702-807d-4746-ab19-4e8c32cb4944",e._sentryDebugIdIdentifier="sentry-dbid-a1c04702-807d-4746-ab19-4e8c32cb4944")}catch{}})();const g={class:"runner"},y=u({__name:"Login",setup(e){const o=m(),r=l(),a=b(),c=async()=>{const{redirect:t,...s}=r.query;if(t){await o.push({path:t,query:s,params:r.params});return}o.push({name:"playerHome",query:s})};return(t,s)=>(_(),i("div",g,[d(p,{"logo-url":n(a).state.workspace?.logoUrl??void 0,"brand-name":n(a).state.workspace?.brandName,locale:n(a).state.workspace?.language??"en",onDone:c},null,8,["logo-url","brand-name","locale"])]))}}),L=f(y,[["__scopeId","data-v-12c690e1"]]);export{L as default};
//# sourceMappingURL=Login-DJRMeKcb.js.map
